
::: banks.prompt.Prompt
    options:
      inherited_members: true

::: banks.prompt.AsyncPrompt

::: banks.registries.directory.DirectoryPromptRegistry
    options:
      inherited_members: true

::: banks.registries.file.FilePromptRegistry
    options:
      inherited_members: true

::: banks.registries.redis.RedisPromptRegistry
    options:
      inherited_members: true
